@@ -6,10 +6,11 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, List, Optional, Union
 
 from fastapi import Request
-from fastapi.responses import HTMLResponse
+from fastapi.responses import Response
 from fastapi.templating import Jinja2Templates
 
-from . import globals, vue
+from . import globals
+from .dependencies import generate_js_imports, generate_vue_content
 from .element import Element
 from .favicon import get_favicon_url
 from .task_logger import create_task
@@ -24,9 +25,10 @@ class Client:
 
     def __init__(self, page: 'page', *, shared: bool = False) -> None:
         self.id = str(uuid.uuid4())
+        self.created = time.time()
         globals.clients[self.id] = self
 
-        self.elements: Dict[str, Element] = {}
+        self.elements: Dict[int, Element] = {}
         self.next_element_id: int = 0
         self.is_waiting_for_handshake: bool = False
         self.environ: Optional[Dict[str, Any]] = None
@@ -34,7 +36,8 @@ class Client:
 
         with Element('q-layout', _client=self).props('view="HHH LpR FFF"') as self.layout:
             with Element('q-page-container'):
-                self.content = Element('div').classes('q-pa-md column items-start gap-4')
+                with Element('q-page'):
+                    self.content = Element('div').classes('q-pa-md column items-start gap-4')
 
         self.waiting_javascript_commands: Dict[str, str] = {}
 
@@ -61,9 +64,9 @@ class Client:
     def __exit__(self, *_):
         self.content.__exit__()
 
-    def build_response(self, request: Request, status_code: int = 200) -> HTMLResponse:
+    def build_response(self, request: Request, status_code: int = 200) -> Response:
         prefix = request.headers.get('X-Forwarded-Prefix', '')
-        vue_html, vue_styles, vue_scripts = vue.generate_vue_content()
+        vue_html, vue_styles, vue_scripts = generate_vue_content()
         elements = json.dumps({id: element.to_dict() for id, element in self.elements.items()})
         return templates.TemplateResponse('index.html', {
             'request': request,
@@ -72,12 +75,13 @@ class Client:
             'head_html': self.head_html,
             'body_html': f'{self.body_html}\n{vue_html}\n{vue_styles}',
             'vue_scripts': vue_scripts,
-            'js_imports': vue.generate_js_imports(prefix),
+            'js_imports': generate_js_imports(prefix),
             'title': self.page.resolve_title(),
-            'favicon_url': get_favicon_url(self.page),
+            'favicon_url': get_favicon_url(self.page, prefix),
             'dark': str(self.page.resolve_dark()),
             'prefix': prefix,
-        }, status_code, {'Cache-Control': 'no-store'})
+            'socket_io_js_extra_headers': globals.socket_io_js_extra_headers,
+        }, status_code, {'Cache-Control': 'no-store', 'X-NiceGUI-Content': 'page'})
 
     async def handshake(self, timeout: float = 3.0, check_interval: float = 0.1) -> None:
         self.is_waiting_for_handshake = True
@@ -97,7 +101,7 @@ class Client:
         }
         create_task(globals.sio.emit('run_javascript', command, room=self.id))
         if not respond:
-            return
+            return None
         deadline = time.time() + timeout
         while request_id not in self.waiting_javascript_commands:
             if time.time() > deadline:
