@@ -1,9 +1,10 @@
 from dataclasses import dataclass
 from typing import Callable, Dict, List, Optional, Union
 
+from ..dependencies import register_component
 from ..element import Element
 from ..events import SceneClickEventArguments, SceneClickHit, handle_event
-from ..vue import register_component
+from ..globals import socket_id
 from .scene_object3d import Object3D
 from .scene_objects import Scene as SceneObject
 
@@ -70,13 +71,14 @@ class Scene(Element):
         self.stack: List[Union[Object3D, SceneObject]] = [SceneObject()]
         self.camera: SceneCamera = SceneCamera()
         self.on_click = on_click
-        self.on('connect', self.handle_connect)
+        self.on('init', self.handle_init)
         self.on('click3d', self.handle_click)
 
-    def handle_connect(self, _) -> None:
-        self.run_method('init')
-        for object in self.objects.values():
-            object.send()
+    def handle_init(self, msg: Dict) -> None:
+        with socket_id(msg['args']):
+            self.move_camera(duration=0)
+            for object in self.objects.values():
+                object.send()
 
     def handle_click(self, msg: Dict) -> None:
         arguments = SceneClickEventArguments(
