@@ -21,6 +21,6 @@ def error_content(status_code: int, exception: Union[str, Exception] = '') -> No
 
     with ui.column().classes('w-full py-20 items-center gap-0'):
         ui.html((Path(__file__).parent / 'static' / 'sad_face.svg').read_text()).classes('w-32 py-5')
-        ui.label(status_code).classes('text-6xl py-5')
+        ui.label(str(status_code)).classes('text-6xl py-5')
         ui.label(title).classes('text-xl py-5')
         ui.label(message).classes('text-lg text-gray-500')
