@@ -1,5 +1,6 @@
 import asyncio
 import logging
+from contextlib import contextmanager
 from enum import Enum
 from typing import TYPE_CHECKING, Awaitable, Callable, Dict, List, Optional, Union
 
@@ -21,7 +22,7 @@ class State(Enum):
 
 app: FastAPI
 sio: AsyncServer
-server: Optional[Server] = None
+server: Server
 loop: Optional[asyncio.AbstractEventLoop] = None
 log: logging.Logger = logging.getLogger('nicegui')
 state: State = State.STOPPED
@@ -34,13 +35,14 @@ favicon: Optional[str]
 dark: Optional[bool]
 binding_refresh_interval: float
 excludes: List[str]
+socket_io_js_extra_headers: Dict = {}
 
+_socket_id: Optional[str] = None
 slot_stacks: Dict[int, List['Slot']] = {}
 clients: Dict[str, 'Client'] = {}
-index_client: 'Client' = ...
+index_client: 'Client'
 
 page_routes: Dict[Callable, str] = {}
-favicons: Dict[str, Optional[str]] = {}
 tasks: List[asyncio.tasks.Task] = []
 
 startup_handlers: List[Union[Callable, Awaitable]] = []
@@ -73,3 +75,11 @@ def get_slot() -> 'Slot':
 
 def get_client() -> 'Client':
     return get_slot().parent.client
+
+
+@contextmanager
+def socket_id(id: str) -> None:
+    global _socket_id
+    _socket_id = id
+    yield
+    _socket_id = None
