@@ -8,6 +8,7 @@ from fastapi import Request, Response
 from . import globals
 from .async_updater import AsyncUpdater
 from .client import Client
+from .favicon import create_favicon_route
 from .task_logger import create_task
 
 
@@ -26,7 +27,7 @@ class page:
 
         :param path: route of the new page (path must start with '/')
         :param title: optional page title
-        :param favicon: optional relative filepath to a favicon (default: `None`, NiceGUI icon will be used)
+        :param favicon: optional relative filepath or absolute URL to a favicon (default: `None`, NiceGUI icon will be used)
         :param dark: whether to use Quasar's dark mode (defaults to `dark` argument of `run` command)
         :param response_timeout: maximum time for the decorated function to build the page (default: 3.0)
         """
@@ -36,17 +37,17 @@ class page:
         self.dark = dark
         self.response_timeout = response_timeout
 
-        globals.favicons[self.path] = favicon
+        create_favicon_route(self.path, favicon)
 
     def resolve_title(self) -> str:
         return self.title if self.title is not None else globals.title
 
     def resolve_dark(self) -> Optional[bool]:
-        return str(self.dark if self.dark is not ... else globals.dark)
+        return self.dark if self.dark is not ... else globals.dark
 
     def __call__(self, func: Callable) -> Callable:
         # NOTE we need to remove existing routes for this path to make sure only the latest definition is used
-        globals.app.routes[:] = [r for r in globals.app.routes if r.path != self.path]
+        globals.app.routes[:] = [r for r in globals.app.routes if getattr(r, 'path', None) != self.path]
         parameters_of_decorated_func = list(inspect.signature(func).parameters.keys())
 
         async def decorated(*dec_args, **dec_kwargs) -> Response:
@@ -58,7 +59,7 @@ class page:
                     dec_kwargs['client'] = client
                 result = func(*dec_args, **dec_kwargs)
             if inspect.isawaitable(result):
-                async def wait_for_result() -> Response:
+                async def wait_for_result() -> None:
                     with client:
                         await AsyncUpdater(result)
                 task = create_task(wait_for_result())
